@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -86,6 +86,8 @@ public class AdminParser extends CLIParser {
     private final ArrayList<OptionInfo> optinfolist = new ArrayList<OptionInfo>();
 
     private String appname = null;
+    
+    private String usage = "";
 
     private CLIOption csvImportOption = null;
 
@@ -353,6 +355,12 @@ public class AdminParser extends CLIParser {
             return retval;
         }
     }
+    
+    public final CLIOption addOption(final char shortForm, final String longForm, final String description, final NeededQuadState needed) {
+        final CLIOption retval = this.addBooleanOption(shortForm, longForm);
+        this.optinfolist.add(new OptionInfo(needed, retval, shortForm, longForm, description));
+        return retval;
+    }
 
     public final boolean checkNoNewLine() {
         if (null != this.getOptionValue(this.noNewlineOption)) {
@@ -501,7 +509,8 @@ public class AdminParser extends CLIParser {
     }
 
     public final void printUsage() {
-        System.out.println("Usage: " + this.appname);
+        System.out.print("Usage: " + this.appname);
+        System.out.println(" " + usage);
 
         for (final OptionInfo optInfo : this.optinfolist) {
             if (!optInfo.extended && !optInfo.hidden) {
@@ -521,6 +530,7 @@ public class AdminParser extends CLIParser {
 
     public final void printUsageExtended() {
         System.out.println("Usage: " + this.appname);
+        System.out.println(" " + usage);
 
         for (final OptionInfo optInfo : this.optinfolist) {
             basicOutput(optInfo);
@@ -628,4 +638,12 @@ public class AdminParser extends CLIParser {
     public Map<String, Map<String, String>> getDynamicArguments() {
         return dynamicMaps;
     }
+    
+    public void setUsage(String usage) {
+        this.usage = usage;
+    }
+    
+    public String getUsage() {
+        return usage;
+    }
 }
