@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,6 +60,7 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.Map;
 import java.util.Set;
+
 import javax.management.AttributeNotFoundException;
 import javax.management.InstanceNotFoundException;
 import javax.management.IntrospectionException;
@@ -74,6 +75,7 @@ import javax.management.ObjectInstance;
 import javax.management.ObjectName;
 import javax.management.ReflectionException;
 import javax.management.openmbean.CompositeDataSupport;
+
 import com.openexchange.admin.console.AdminParser.NeededQuadState;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 
@@ -148,6 +150,12 @@ public class StatisticTools extends AbstractJMXTools {
 
     private static final String OPT_MEMORYPOOL_STATS_LONG = "memorypool";
 
+    private static final char OPT_NIO_BUFFER_STATS_SHORT = 'n';
+    private static final String OPT_NIO_BUFFER_STATS_LONG = "niobufferstats";
+
+    private static final char OPT_RT_BUFFER_STATS_SHORT= 'R';
+    private static final String OPT_RT_BUFFER_STATS_LONG = "rtstats";
+
     private CLIOption xchangestats = null;
     private CLIOption threadpoolstats = null;
     private CLIOption runtimestats = null;
@@ -175,6 +183,7 @@ public class StatisticTools extends AbstractJMXTools {
     private CLIOption miscstats = null;
     private CLIOption overviewstats = null;
     private CLIOption memorypoolstats = null;
+    private CLIOption niobufferstats = null;
 
     /**
      * Option for garbage collection statistics
@@ -255,7 +264,8 @@ public class StatisticTools extends AbstractJMXTools {
             System.out.print(showGrizzlyData(mbc));
             System.out.print(showGcData(mbc));
             System.out.print(getStats(mbc, "com.openexchange.usm.session", "name", "com.openexchange.usm.session.impl.USMSessionInformation"));
-            System.out.println(showEventAdminData(mbc));
+            System.out.print(showEventAdminData(mbc));
+            System.out.println(showNioBufferData(mbc));
             count++;
         }
         if (null != parser.getOptionValue(this.showoperation) && 0 == count) {
@@ -321,6 +331,10 @@ public class StatisticTools extends AbstractJMXTools {
             System.out.print(getStats(mbc, "java.lang:type=OperatingSystem"));
             count++;
         }
+        if (null != parser.getOptionValue(this.niobufferstats) && 0 == count) {
+            System.out.print(showNioBufferData(mbc));
+            count++;
+        }
         if (0 == count) {
             System.err.println(new StringBuilder("No option selected (").append(OPT_STATS_LONG).append(", ").append(
                 OPT_RUNTIME_STATS_LONG).append(", ").append(OPT_OS_STATS_LONG).append(", ").append(OPT_THREADING_STATS_LONG).append(
@@ -570,6 +584,14 @@ public class StatisticTools extends AbstractJMXTools {
         this.miscstats = setLongOpt(parser, OPT_MISC_STATS_LONG, "shows stats for general and threading", false, false);
         this.overviewstats = setLongOpt(parser, OPT_OVERVIEW_STATS_LONG, "shows stats for pooling and OperatingSystem", false, false);
         this.memorypoolstats = setLongOpt(parser, OPT_MEMORYPOOL_STATS_LONG, "shows stats for memory pool usage of the Java runtime", false, false);
+        this.niobufferstats = setShortLongOpt(
+            parser,
+            OPT_NIO_BUFFER_STATS_SHORT,
+            OPT_NIO_BUFFER_STATS_LONG,
+            "shows the NIO buffer stats",
+            false,
+            NeededQuadState.notneeded);
+
 
     }
 
@@ -587,6 +609,7 @@ public class StatisticTools extends AbstractJMXTools {
         sb.append(showGeneralMonitor(con));
         sb.append(showMailInterfaceMonitor(con));
         sb.append(showPooling(con));
+        sb.append(showRateLimiterMonitor(con));
         return sb.toString();
     }
 
@@ -610,6 +633,10 @@ public class StatisticTools extends AbstractJMXTools {
         return getStats(con, "com.openexchange.monitoring:name=AJPv13ServerThreadsMonitor");
     }
 
+    private static StringBuffer showRateLimiterMonitor(MBeanServerConnection con) throws IOException, InstanceNotFoundException, MBeanException, AttributeNotFoundException, ReflectionException, IntrospectionException, MalformedObjectNameException {
+        return getStats(con, "com.openexchange.monitoring:name=RateLimiterMonitor");
+    }
+
     private static StringBuffer showCallMonitor(MBeanServerConnection con) throws IOException, InstanceNotFoundException, MBeanException, AttributeNotFoundException, ReflectionException, IntrospectionException, MalformedObjectNameException {
         return getStats(con, "com.openexchange.admin.monitor:name=CallMonitor");
     }
@@ -877,6 +904,54 @@ public class StatisticTools extends AbstractJMXTools {
         return uptimeHours;
     }
 
+
+    /**
+     * Show NIO buffer stats
+     * @param mbeanServerConnection
+     * @return
+     * @throws InstanceNotFoundException
+     * @throws AttributeNotFoundException
+     * @throws IntrospectionException
+     * @throws MalformedObjectNameException
+     * @throws MBeanException
+     * @throws ReflectionException
+     * @throws IOException
+     */
+    static String showNioBufferData(final MBeanServerConnection mbeanServerConnection) throws InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MalformedObjectNameException, MBeanException, ReflectionException, IOException {
+        return getStats(mbeanServerConnection, "java.nio:type=BufferPool,name=direct")
+        .append(getStats(mbeanServerConnection, "java.nio:type=BufferPool,name=mapped"))
+        .toString();
+    }
+
+    static String showRtData(final MBeanServerConnection mbeanServerConnection) {
+        String runLoopFillSum = "RunLoopFillSum";
+        StringBuilder sb = new StringBuilder();
+        try {
+            final ObjectName objectName = new ObjectName("com.openexchange.realtime:name=RunLoopManager");
+            Object fillSum = mbeanServerConnection.getAttribute(objectName, runLoopFillSum);
+            if (fillSum instanceof Map) {
+                Map<?, ?> fillSums = Map.class.cast(fillSum);
+                for (Map.Entry<?, ?> entry : fillSums.entrySet()) {
+                    sb.append(objectName);
+                    sb.append(',');
+                    sb.append(runLoopFillSum);
+                    sb.append(',');
+                    sb.append(entry.getKey());
+                    sb.append(" = ");
+                    sb.append(entry.getValue());
+                    sb.append(LINE_SEPARATOR);
+                }
+            }
+        } catch (final Exception e) {
+            sb.append("com.openexchange.realtime");
+            sb.append(" = ");
+            sb.append('[');
+            sb.append(e.toString());
+            sb.append(']');
+        }
+        return sb.toString();
+    }
+
     private static String extractTextInBrackets(final String value, final int startIdx) {
         final StringBuilder stringBuilder = new StringBuilder();
         if (-1 < startIdx && startIdx < value.length()) {
