@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,11 +68,9 @@ import com.openexchange.admin.tools.PropertyHandlerExtended;
 import com.openexchange.tools.pipesnfilters.Filter;
 
 /**
- * This interface provides an abstraction to the storage of the context
- * information
+ * This interface provides an abstraction to the storage of the context information
  *
  * @author d7
- *
  */
 public abstract class OXContextStorageInterface {
 
@@ -89,6 +87,7 @@ public abstract class OXContextStorageInterface {
 
     /**
      * Creates a new instance implementing the group storage interface.
+     * 
      * @return an instance implementing the group storage interface.
      * @throws com.openexchange.admin.rmi.exceptions.StorageException Storage exception
      */
@@ -220,7 +219,6 @@ public abstract class OXContextStorageInterface {
      */
     public abstract Context create(final Context ctx, final User admin_user, final UserModuleAccess access) throws StorageException, InvalidDataException;
 
-
     /**
      * @param ctx
      * @throws StorageException
@@ -243,12 +241,33 @@ public abstract class OXContextStorageInterface {
      */
     public abstract void disable(final Context ctx, final MaintenanceReason reason) throws StorageException;
 
+    /**
+     * Disables all contexts in a schema and sets the given maintenance reason. Contexts that are already disabled will be ignored and keep
+     * their original reason.
+     *
+     * @param schema
+     * @param reason
+     * @throws StorageException
+     */
+    public abstract void disable(final String schema, final MaintenanceReason reason) throws StorageException;
+
     /**
      * @param ctx
      * @throws StorageException
      */
     public abstract void enable(final Context ctx) throws StorageException;
 
+    /**
+     * Enables all contexts in a schema which are currently disabled with to the given maintenance reason. Contexts that are disabled with
+     * any other maintenance reason will not be enabled. If no reason is given, all disabled contexts are enabled. For every context that is
+     * enabled, the reason ID is set to NULL.
+     *
+     * @param schema
+     * @param reason The reason or <code>null</code>
+     * @throws StorageException
+     */
+    public abstract void enable(final String schema, final MaintenanceReason reason) throws StorageException;
+
     /**
      * @param reason
      * @throws StorageException
@@ -274,8 +293,18 @@ public abstract class OXContextStorageInterface {
      */
     public abstract Context[] searchContextByFilestore(final Filestore filestore) throws StorageException;
 
+    /**
+     * Gets all contexts that belong to the given schema.
+     *
+     * @param schema
+     * @return
+     * @throws StorageException
+     */
+    public abstract List<Integer> getContextIdsBySchema(final String schema) throws StorageException;
+
     /**
      * This method deletes all inaccessible data in a context.
+     * 
      * @param ctx Context.
      * @throws StorageException if some problem occurs.
      */
@@ -296,5 +325,23 @@ public abstract class OXContextStorageInterface {
      */
     public abstract void enableAll(final String additionaltable, final String sqlconjunction) throws StorageException;
 
+    /**
+     * Updates the context references after a replay
+     * 
+     * @param sourceSchema The source schema
+     * @param targetSchema The target schema
+     * @param targetClusterId The target cluster identifier
+     * @throws StorageException
+     */
+    public abstract void updateContextReferences(final String sourceSchema, final String targetSchema, final int targetClusterId) throws StorageException;
+
+    /**
+     * Create a new database schema
+     * 
+     * @param targetClusterId The identifier of the target cluster
+     * @return The name of the new database schema
+     * @throws StorageException
+     */
+    public abstract String createSchema(int targetClusterId) throws StorageException;
 
 }
