@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,11 +80,13 @@ import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.services.AdminServiceRegistry;
 import com.openexchange.admin.storage.sqlStorage.OXUtilSQLStorage;
 import com.openexchange.admin.tools.AdminCache;
+import com.openexchange.exception.OXException;
 import com.openexchange.groupware.impl.IDGenerator;
 import com.openexchange.threadpool.ThreadPoolCompletionService;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.threadpool.ThreadPools;
 import com.openexchange.tools.arrays.Collections;
+import com.openexchange.tools.file.external.QuotaFileStorages;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
@@ -1526,7 +1528,9 @@ public class OXUtilMySQLStorage extends OXUtilSQLStorage {
         PreparedStatement stmt = null;
         ResultSet result = null;
         try {
-            stmt = con.prepareStatement("SELECT cid,used FROM filestore_usage");
+            boolean hasUserColumn = QuotaFileStorages.hasUserColumn(con, representativeContextID);
+
+            stmt = con.prepareStatement(hasUserColumn ? "SELECT cid,used FROM filestore_usage WHERE user=0" : "SELECT cid,used FROM filestore_usage");
             result = stmt.executeQuery();
             while (result.next()) {
                 final int cid = result.getInt(1);
@@ -1535,6 +1539,8 @@ public class OXUtilMySQLStorage extends OXUtilSQLStorage {
             }
         } catch (final SQLException e) {
             throw new StorageException(e);
+        } catch (final OXException e) {
+            throw new StorageException(e);
         } finally {
             closeSQLStuff(result, stmt);
             try {
@@ -1587,7 +1593,9 @@ public class OXUtilMySQLStorage extends OXUtilSQLStorage {
         ResultSet result = null;
         long quotaUsed = 0;
         try {
-            stmt = con.prepareStatement("SELECT used FROM filestore_usage WHERE cid=?");
+            boolean hasUserColumn = QuotaFileStorages.hasUserColumn(con, cid);
+
+            stmt = con.prepareStatement(hasUserColumn ? "SELECT used FROM filestore_usage WHERE cid=? AND user=0" : "SELECT used FROM filestore_usage WHERE cid=?");
             stmt.setInt(1, cid);
             result = stmt.executeQuery();
             // One line per context in that table. cid is PRIMARY KEY.
@@ -1597,6 +1605,9 @@ public class OXUtilMySQLStorage extends OXUtilSQLStorage {
         } catch (final SQLException e) {
             LOG.error("SQL Error", e);
             throw new StorageException(e);
+        } catch (final OXException e) {
+            LOG.error("OX Error", e);
+            throw new StorageException(e);
         } finally {
             closeSQLStuff(result, stmt);
             if (null != con) {
@@ -1662,4 +1673,41 @@ public class OXUtilMySQLStorage extends OXUtilSQLStorage {
         }
         return usage;
     }
+
+    @Override
+    public int getWritePoolIdForCluster(int clusterId) throws StorageException {
+        final Connection con;
+        try {
+            con = cache.getConnectionForConfigDB();
+        } catch (final PoolException e) {
+            LOG.error("Pool Error", e);
+            throw new StorageException(e);
+        }
+
+        PreparedStatement stmt = null;
+        ResultSet rs = null;
+        try {
+            String getDbInfo = "SELECT write_db_pool_id FROM db_cluster WHERE cluster_id = ?";
+            stmt = con.prepareStatement(getDbInfo);
+            stmt.setInt(1, clusterId);
+            rs = stmt.executeQuery();
+
+            if (rs.next()) {
+                return rs.getInt(1);
+            } else {
+                LOG.error("The specified cluster id '{}' has no database pool references", clusterId);
+                throw new StorageException("The specified cluster id '" + clusterId + "' has no database pool references");
+            }
+        } catch (SQLException e) {
+            LOG.error("SQL Error", e);
+            throw new StorageException(e);
+        } finally {
+            closeSQLStuff(rs, stmt);
+            try {
+                cache.pushConnectionForConfigDB(con);
+            } catch (final PoolException e) {
+                LOG.error("Error pushing configdb connection to pool!", e);
+            }
+        }
+    }
 }
