@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -76,9 +76,9 @@ public class CreateContactsTables extends AbstractCreateTableImpl {
         + "field02 VARCHAR(128),"
         + "field03 VARCHAR(128),"
         + "field04 VARCHAR(128),"
-        + "cid INT4,"
-        + "uuid binary(16) DEFAULT NULL,"
-        + "PRIMARY KEY(cid, uuid),"
+        + "cid INT4 NOT NULL,"
+        + "uuid binary(16) NOT NULL,"
+        + "PRIMARY KEY(uuid, cid, intfield01),"
         + "INDEX (intfield01, cid),"
         + "INDEX (intfield01, intfield02, intfield03, cid)"
         + ") ENGINE  = InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
@@ -102,7 +102,7 @@ public class CreateContactsTables extends AbstractCreateTableImpl {
         + "field04 VARCHAR(128),"
         + "cid INT4 NOT NULL,"
         + "uuid binary(16) NOT NULL,"
-        + "PRIMARY KEY (cid, uuid),"
+        + "PRIMARY KEY (uuid, cid, intfield01),"
         + "INDEX (intfield01, cid),"
         + "INDEX (intfield01, intfield02, intfield03, cid)"
         + ") ENGINE = InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
