@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,6 +57,7 @@ import com.openexchange.admin.rmi.exceptions.InvalidCredentialsException;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.rmi.impl.BasicAuthenticator;
+import com.openexchange.admin.services.AdminServiceRegistry;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.auth.Authenticator;
 import com.openexchange.auth.Credentials;
@@ -82,6 +83,24 @@ public final class AuthenticatorImpl implements Authenticator, Reloadable {
         super();
     }
 
+    @Override
+    public boolean isMasterAuthenticationDisabled() throws OXException {
+        ConfigurationService configService = AdminServiceRegistry.getInstance().getService(ConfigurationService.class);
+        if (null == configService) {
+            return false;
+        }
+        return configService.getBoolProperty("MASTER_AUTHENTICATION_DISABLED", false);
+    }
+
+    @Override
+    public boolean isContextAuthenticationDisabled() throws OXException {
+        ConfigurationService configService = AdminServiceRegistry.getInstance().getService(ConfigurationService.class);
+        if (null == configService) {
+            return false;
+        }
+        return configService.getBoolProperty("CONTEXT_AUTHENTICATION_DISABLED", false);
+    }
+
     @Override
     public void doAuthentication(final Credentials authdata) throws OXException {
         try {
