@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -105,8 +105,8 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
     }
 
     @Override
-    public void change(final Context ctx, final Resource res, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException, NoSuchResourceException {
-        auth = auth == null ? new Credentials("","") : auth;
+    public void change(final Context ctx, final Resource res, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException, NoSuchResourceException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
         try {
             doNullCheck(res);
         } catch (final InvalidDataException e3) {
@@ -115,6 +115,10 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
             throw invalidDataException;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         try {
             basicauth.doAuthentication(auth,ctx);
         } catch (final InvalidDataException e1) {
@@ -202,8 +206,8 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
     }
 
     @Override
-    public Resource create(final Context ctx, final Resource res, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException {
-       auth = auth == null ? new Credentials("","") : auth;
+    public Resource create(final Context ctx, final Resource res, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException {
+       Credentials auth = credentials == null ? new Credentials("","") : credentials;
        try {
            doNullCheck(res);
            doNullCheck(res.getName());
@@ -212,6 +216,10 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
            throw e3;
        }
 
+       if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+           auth.setLogin(auth.getLogin().toLowerCase());
+       }
+
        try {
            basicauth.doAuthentication(auth,ctx);
        } catch( final InvalidDataException e) {
@@ -299,8 +307,8 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
     }
 
     @Override
-    public void delete(final Context ctx, final Resource res, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException, NoSuchResourceException {
-        auth = auth == null ? new Credentials("","") : auth;
+    public void delete(final Context ctx, final Resource res, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException, NoSuchResourceException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
         try {
             doNullCheck(res);
         } catch (final InvalidDataException e3) {
@@ -308,6 +316,10 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
             throw e3;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         try {
             basicauth.doAuthentication(auth,ctx);
 
@@ -364,8 +376,8 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
     }
 
     @Override
-    public Resource getData(final Context ctx, final Resource res, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException, NoSuchResourceException {
-        auth = auth == null ? new Credentials("","") : auth;
+    public Resource getData(final Context ctx, final Resource res, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException, NoSuchResourceException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
         try {
             doNullCheck(res);
         } catch (final InvalidDataException e3) {
@@ -373,6 +385,10 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
             throw e3;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         try {
             basicauth.doAuthentication(auth,ctx);
         } catch (final InvalidDataException e) {
@@ -414,8 +430,8 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
     }
 
     @Override
-    public Resource[] getData(final Context ctx, final Resource[] resources, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, NoSuchResourceException, DatabaseUpdateException {
-        auth = auth == null ? new Credentials("","") : auth;
+    public Resource[] getData(final Context ctx, final Resource[] resources, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, NoSuchResourceException, DatabaseUpdateException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
         try {
             doNullCheck((Object[])resources);
         } catch (final InvalidDataException e3) {
@@ -423,6 +439,10 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
             throw e3;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         try {
             basicauth.doAuthentication(auth,ctx);
 
@@ -481,8 +501,8 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
     }
 
     @Override
-    public Resource[] list(final Context ctx, final String pattern, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException {
-        auth = auth == null ? new Credentials("","") : auth;
+    public Resource[] list(final Context ctx, final String pattern, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException,InvalidDataException, DatabaseUpdateException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
         try {
             doNullCheck(pattern);
         } catch (final InvalidDataException e3) {
@@ -490,6 +510,10 @@ public class OXResource extends OXCommonImpl implements OXResourceInterface{
             throw e3;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         try {
             if(pattern.length()==0){
                 throw new InvalidDataException("Invalid pattern!");
