@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -139,6 +139,9 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
         }
 
         Credentials auth = credentials == null ? new Credentials("", "") : credentials;
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
 
         try {
             basicauth.doAuthentication(auth, ctx);
@@ -185,7 +188,11 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
         if (null == user) {
             throw new InvalidDataException("Missing user.");
         }
+
         Credentials auth = credentials == null ? new Credentials("", "") : credentials;
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
 
         LOGGER.debug("{} - {} - {} | {} - {}", ctx, user, (null == capsToAdd ? "" : capsToAdd.toString()), (null == capsToRemove ? "" : capsToRemove.toString()), auth);
 
@@ -261,6 +268,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw invalidDataException;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         // SPECIAL USER AUTH CHECK FOR THIS METHOD!
         // check if credentials are from oxadmin or from an user
         Integer userid = null;
@@ -410,6 +421,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw invalidDataException;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
             LOGGER.debug("{} - {} - {} - {}", ctx, user, moduleAccess, auth);
 
         try {
@@ -496,6 +511,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw invalidDataException;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         LOGGER.debug("{} - {} - {} - {}", ctx, user, access_combination_name, auth);
 
         try {
@@ -622,6 +641,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw e3;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         LOGGER.debug("{} - {} - {} - {}", ctx, usrdata, access_combination_name, auth);
 
         basicauth.doAuthentication(auth, ctx);
@@ -657,6 +680,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw e3;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
             LOGGER.debug("{} - {} - {}", ctx, usrdata, auth);
 
         basicauth.doAuthentication(auth, ctx);
@@ -888,6 +915,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw e;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         basicauth.doAuthentication(auth,ctx);
 
             LOGGER.debug("{} - {} - {}", ctx, Arrays.toString(users), auth);
@@ -1024,7 +1055,7 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
 
     @Override
     public User[] getData(final Context ctx, final User[] users, final Credentials credentials) throws StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, NoSuchUserException, DatabaseUpdateException {
-        final Credentials auth = credentials == null ? new Credentials("","") : credentials;
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
         try {
             doNullCheck((Object[]) users);
         } catch (final InvalidDataException e1) {
@@ -1040,6 +1071,11 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             LOGGER.error("", e);
             throw e;
         }
+
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         LOGGER.debug("{} - {} - {}", ctx, Arrays.toString(users), auth);
         try {
             // enable check who wants to get data if authentication is enabled
@@ -1156,6 +1192,11 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             LOGGER.error("", invalidDataException);
             throw invalidDataException;
         }
+
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
             LOGGER.debug("{} - {} - {}", ctx, user, auth);
         try {
             basicauth.doAuthentication(auth, ctx);
@@ -1202,6 +1243,11 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             LOGGER.error("", invalidDataException);
             throw invalidDataException;
         }
+
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
             LOGGER.debug("{} - {} - {}", ctx, user, auth);
         try {
             basicauth.doAuthentication(auth, ctx);
@@ -1251,6 +1297,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw e1;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
             LOGGER.debug("{} - {}", ctx, auth);
 
         basicauth.doAuthentication(auth,ctx);
@@ -1272,6 +1322,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw e1;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
             LOGGER.debug("{} - {}", ctx, auth);
 
         basicauth.doAuthentication(auth,ctx);
@@ -1319,7 +1373,7 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
                 if (prop.getUserProp(AdminProperties.User.CHECK_NOT_ALLOWED_CHARS, true)) {
                     tool.validateUserName(newuser.getName());
                 }
-                if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, true)) {
+                if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
                     newuser.setName(newuser.getName().toLowerCase());
                 }
             }
@@ -1337,13 +1391,20 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             }
         }
 
-        final String lang = newuser.getLanguage();
-        if (lang != null && lang.indexOf('_') < 0) {
-            throw new InvalidDataException("Language must contain an underscore, e.g. en_US.");
+        {
+            String lang = newuser.getLanguage();
+            if (lang != null && lang.indexOf('_') < 0) {
+                throw new InvalidDataException("Language must contain an underscore, e.g. en_US.");
+            }
         }
 
+        String newDefaultSenderAddress = newuser.getDefaultSenderAddress();
+        String newPrimaryEmail = newuser.getPrimaryEmail();
+        String newEmail1 = newuser.getEmail1();
+        boolean mailCheckNeeded = (null != newDefaultSenderAddress) || (null != newPrimaryEmail) || (null != newEmail1) || (null != newuser.getAliases());
+
         if (prop.getUserProp(AdminProperties.User.PRIMARY_MAIL_UNCHANGEABLE, true)) {
-            if (newuser.getPrimaryEmail() != null && !newuser.getPrimaryEmail().equalsIgnoreCase(dbuser.getPrimaryEmail())) {
+            if (newPrimaryEmail != null && !newPrimaryEmail.equalsIgnoreCase(dbuser.getPrimaryEmail())) {
                 throw new InvalidDataException("primary mail must not be changed");
             }
         }
@@ -1355,16 +1416,16 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             newuser.setPasswordMech(dbuser.getPasswordMech());
         }
 
-        if (!tool.isContextAdmin(ctx, newuser.getId().intValue())) {
+        if (mailCheckNeeded && !tool.isContextAdmin(ctx, newuser.getId().intValue())) {
             // checks below throw InvalidDataException
             tool.checkValidEmailsInUserObject(newuser);
-            HashSet<String> useraliases = newuser.getAliases();
+            Set<String> useraliases = newuser.getAliases();
             if (useraliases == null) {
                 useraliases = dbuser.getAliases();
             }
             if (null != useraliases) {
-                final HashSet<String> tmp = new HashSet<String>(useraliases.size());
-                for (final String email : useraliases) {
+                Set<String> tmp = new HashSet<String>(useraliases.size());
+                for (String email : useraliases) {
                     tmp.add(IDNA.toIDN(email));
                 }
                 useraliases = tmp;
@@ -1372,10 +1433,7 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
                 useraliases = new HashSet<String>(1);
             }
 
-            final String defaultSenderAddress = newuser.getDefaultSenderAddress();
-            final String primaryEmail = newuser.getPrimaryEmail();
-            final String email1 = newuser.getEmail1();
-            if (primaryEmail != null && email1 != null && !primaryEmail.equalsIgnoreCase(email1)) {
+            if (newPrimaryEmail != null && newEmail1 != null && !newPrimaryEmail.equalsIgnoreCase(newEmail1)) {
                 // primary mail value must be same with email1
                 throw new InvalidDataException("email1 not equal with primarymail!");
             }
@@ -1383,54 +1441,39 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             String check_primary_mail;
             String check_email1;
             String check_default_sender_address;
-            if (primaryEmail != null) {
-                check_primary_mail = IDNA.toIDN(primaryEmail);
-                if (!primaryEmail.equalsIgnoreCase(dbuser.getPrimaryEmail())) {
-                    tool.primaryMailExists(ctx, primaryEmail);
+            if (newPrimaryEmail != null) {
+                check_primary_mail = IDNA.toIDN(newPrimaryEmail);
+                if (!newPrimaryEmail.equalsIgnoreCase(dbuser.getPrimaryEmail())) {
+                    tool.primaryMailExists(ctx, newPrimaryEmail);
                 }
             } else {
                 final String email = dbuser.getPrimaryEmail();
                 check_primary_mail = email == null ? email : IDNA.toIDN(email);
             }
 
-            if (email1 != null) {
-                check_email1 = IDNA.toIDN(email1);
+            if (newEmail1 != null) {
+                check_email1 = IDNA.toIDN(newEmail1);
             } else {
                 final String s = dbuser.getEmail1();
                 check_email1 = s == null ? s : IDNA.toIDN(s);
             }
-            if (defaultSenderAddress != null) {
-                check_default_sender_address = IDNA.toIDN(defaultSenderAddress);
+            if (newDefaultSenderAddress != null) {
+                check_default_sender_address = IDNA.toIDN(newDefaultSenderAddress);
             } else {
                 final String s = dbuser.getDefaultSenderAddress();
                 check_default_sender_address = s == null ? s : IDNA.toIDN(s);
             }
 
-            boolean found_primary_mail = useraliases.contains(check_primary_mail);
-            boolean found_email1 = useraliases.contains(check_email1);
-            boolean found_default_sender_address = useraliases.contains(check_default_sender_address);
+            final boolean found_primary_mail = useraliases.contains(check_primary_mail);
+            final boolean found_email1 = useraliases.contains(check_email1);
+            final boolean found_default_sender_address = useraliases.contains(check_default_sender_address);
 
             if (!found_primary_mail || !found_email1 || !found_default_sender_address) {
-                // if any of those is missing, update the alias list like OXToolMySQLStorage.checkCreateUserData does
-                newuser.setAliases(useraliases);
-                newuser.addAlias(check_primary_mail);
-                newuser.addAlias(check_default_sender_address);
-
-                // retest to see if the added values are now present inside the aliasList
-                {
-                    HashSet<String> newUseraliases = newuser.getAliases();
-                    found_primary_mail = newUseraliases.contains(check_primary_mail);
-                    found_email1 = newUseraliases.contains(check_email1);
-                    found_default_sender_address = newUseraliases.contains(check_default_sender_address);
-                    if (!found_primary_mail || !found_email1 || !found_default_sender_address) {
-                        throw new InvalidDataException("primaryMail, Email1 and defaultSenderAddress must be present in set of aliases.");
-                    }
-                }
-
+                throw new InvalidDataException("primaryMail, Email1 and defaultSenderAddress must be present in set of aliases.");
             }
             // added "usrdata.getPrimaryEmail() != null" for this check, else we cannot update user data without mail data
             // which is not very good when just changing the displayname for example
-            if (primaryEmail != null && email1 == null) {
+            if (newPrimaryEmail != null && newEmail1 == null) {
                 throw new InvalidDataException("email1 not sent but required!");
 
             }
@@ -1482,9 +1525,6 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
         return list.toArray(new User[list.size()]);
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.admin.rmi.OXUserInterface#changeModuleAccessGlobal(java.lang.String, com.openexchange.admin.rmi.dataobjects.UserModuleAccess, com.openexchange.admin.rmi.dataobjects.UserModuleAccess, com.openexchange.admin.rmi.dataobjects.Credentials)
-     */
     @Override
     public void changeModuleAccessGlobal(final String filter, final UserModuleAccess addAccess, final UserModuleAccess removeAccess, final Credentials credentials) throws RemoteException, InvalidCredentialsException, StorageException, InvalidDataException {
         final Credentials auth = credentials == null ? new Credentials("","") : credentials;
@@ -1495,6 +1535,11 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             LOGGER.error("", invalidDataException);
             throw invalidDataException;
         }
+
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         try {
             checkForGABRestriction(addAccess);
             checkForGABRestriction(removeAccess);
@@ -1552,8 +1597,8 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
     }
 
     @Override
-    public boolean exists(final Context ctx, final User user, final Credentials credentials) throws RemoteException, InvalidDataException, InvalidCredentialsException, StorageException, DatabaseUpdateException, NoSuchContextException {
-        final Credentials auth = credentials == null ? new Credentials("","") : credentials;
+    public boolean exists(Context ctx, User user, Credentials credentials) throws RemoteException, InvalidDataException, InvalidCredentialsException, StorageException, DatabaseUpdateException, NoSuchContextException {
+        Credentials auth = credentials == null ? new Credentials("","") : credentials;
         try {
             doNullCheck(user);
         } catch (final InvalidDataException e2) {
@@ -1562,6 +1607,10 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
             throw invalidDataException;
         }
 
+        if (prop.getUserProp(AdminProperties.User.AUTO_LOWERCASE, false)) {
+            auth.setLogin(auth.getLogin().toLowerCase());
+        }
+
         try {
             basicauth.doAuthentication(auth, ctx);
         } catch (final InvalidCredentialsException e) {
@@ -1574,23 +1623,25 @@ public class OXUser extends OXCommonImpl implements OXUserInterface {
 
             checkContextAndSchema(ctx);
 
-            if( null != user.getId() ) {
+            if (null != user.getId()) {
                 return tool.existsUser(ctx, user);
-            } else if( null != user.getName() ) {
+            } else if (null != user.getName()) {
                 return tool.existsUserName(ctx, user.getName());
+            } else if (null != user.getDisplay_name()) {
+                return tool.existsDisplayName(ctx, user.getDisplay_name());
             } else {
-                throw new InvalidDataException("Neither id nor name is set in supplied user object");
+                throw new InvalidDataException("Neither identifier, name nor display name set in given user object");
             }
-        } catch (final InvalidCredentialsException e) {
+        } catch (InvalidCredentialsException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final StorageException e) {
+        } catch (StorageException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final DatabaseUpdateException e) {
+        } catch (DatabaseUpdateException e) {
             LOGGER.error("", e);
             throw e;
-        } catch (final NoSuchContextException e) {
+        } catch (NoSuchContextException e) {
             LOGGER.error("", e);
             throw e;
         }
