@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,6 +66,8 @@ import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.tools.AdminCache;
+import com.openexchange.exception.OXException;
+import com.openexchange.tools.file.external.QuotaFileStorages;
 import com.openexchange.tools.pipesnfilters.Filter;
 import com.openexchange.tools.pipesnfilters.PipesAndFiltersException;
 
@@ -120,8 +122,6 @@ public class FilestoreUsageLoader implements Filter<Context, Context> {
         return retval.toArray(new Context[retval.size()]);
     }
 
-    private static final String SQL = "SELECT cid,used FROM filestore_usage";
-
     private Collection<Context> loadUsage(int poolId, String schema, Map<Integer, Context> contexts) throws StorageException {
         final Connection con;
         try {
@@ -129,10 +129,13 @@ public class FilestoreUsageLoader implements Filter<Context, Context> {
         } catch (PoolException e) {
             throw new StorageException(e);
         }
+
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
-            stmt = con.prepareStatement(SQL);
+            boolean hasUserColumn = QuotaFileStorages.hasUserColumn(con, schema);
+
+            stmt = con.prepareStatement(hasUserColumn ? "SELECT cid,used FROM filestore_usage WHERE user=0" : "SELECT cid,used FROM filestore_usage");
             rs = stmt.executeQuery();
             while (rs.next()) {
                 Context context = contexts.get(I(rs.getInt(1)));
@@ -143,6 +146,8 @@ public class FilestoreUsageLoader implements Filter<Context, Context> {
             }
         } catch (SQLException e) {
             throw new StorageException(e.getMessage(), e);
+        } catch (OXException e) {
+            throw new StorageException(e.getMessage(), e);
         } finally {
             closeSQLStuff(rs, stmt);
             try {
